==> Test-Dist-VersionSync-1.1.1.tar.gz: Test-Dist-VersionSync-1.1.1/README.md <==
Test-Dist-VersionSync
=====================

[![Build Status](https://travis-ci.org/guillaumeaubert/Test-Dist-VersionSync.png?branch=master)](https://travis-ci.org/guillaumeaubert/Test-Dist-VersionSync)

Test::Dist::VersionSync verifies that all the modules in a distribution have the same version number.


INSTALLATION
------------

To install this module, run the following commands:

	perl Build.PL
	./Build
	./Build test
	./Build install


SUPPORT AND DOCUMENTATION
-------------------------

After installing, you can find documentation for this module with the
perldoc command.

	perldoc Test::Dist::VersionSync


You can also look for information at:

 * [GitHub's request tracker (report bugs here)]
   (https://github.com/guillaumeaubert/Test-Dist-VersionSync/issues)

 * [AnnoCPAN, Annotated CPAN documentation]
   (http://annocpan.org/dist/Test-Dist-VersionSync)

 * [CPAN Ratings]
   (http://cpanratings.perl.org/d/Test-Dist-VersionSync)

 * [MetaCPAN]
   (https://metacpan.org/release/Test-Dist-VersionSync)


LICENSE AND COPYRIGHT
---------------------

Copyright (C) 2012-2013 Guillaume Aubert

This program is free software: you can redistribute it and/or modify it under
the terms of the GNU General Public License version 3 as published by the Free
Software Foundation.

This program is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
this program. If not, see http://www.gnu.org/licenses/

==> Test-Dist-VersionSync-1.1.2.tar.gz: Test-Dist-VersionSync-1.1.2/README.md <==
Test-Dist-VersionSync
=====================

[![Build Status](https://travis-ci.org/guillaumeaubert/Test-Dist-VersionSync.png?branch=master)](https://travis-ci.org/guillaumeaubert/Test-Dist-VersionSync)
[![Coverage Status](https://coveralls.io/repos/guillaumeaubert/Test-Dist-VersionSync/badge.png?branch=master)](https://coveralls.io/r/guillaumeaubert/Test-Dist-VersionSync?branch=master)

Test::Dist::VersionSync verifies that all the modules in a distribution have the same version number.


INSTALLATION
------------

To install this module, run the following commands:

	perl Build.PL
	./Build
	./Build test
	./Build install


SUPPORT AND DOCUMENTATION
-------------------------

After installing, you can find documentation for this module with the
perldoc command.

	perldoc Test::Dist::VersionSync


You can also look for information at:

 * [GitHub's request tracker (report bugs here)]
   (https://github.com/guillaumeaubert/Test-Dist-VersionSync/issues)

 * [AnnoCPAN, Annotated CPAN documentation]
   (http://annocpan.org/dist/Test-Dist-VersionSync)

 * [CPAN Ratings]
   (http://cpanratings.perl.org/d/Test-Dist-VersionSync)

 * [MetaCPAN]
   (https://metacpan.org/release/Test-Dist-VersionSync)


LICENSE AND COPYRIGHT
---------------------

Copyright (C) 2012-2013 Guillaume Aubert

This program is free software: you can redistribute it and/or modify it under
the terms of the GNU General Public License version 3 as published by the Free
Software Foundation.

This program is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
this program. If not, see http://www.gnu.org/licenses/
